"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupTailwindGenerator = exports.addTailwindConfig = void 0;
const devkit_1 = require("@nx/devkit");
const add_tailwind_helpers_1 = require("./add-tailwind-helpers");
async function addTailwindConfig(tree, projectName) {
    await setupTailwindGenerator(tree, {
        project: projectName,
    });
}
exports.addTailwindConfig = addTailwindConfig;
async function setupTailwindGenerator(tree, rawOptions) {
    const options = (0, add_tailwind_helpers_1.normalizeOptions)(rawOptions);
    const project = (0, devkit_1.readProjectConfiguration)(tree, options.project);
    const tailwindInstalledVersion = (0, add_tailwind_helpers_1.detectTailwindInstalledVersion)(tree);
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    let installTask = () => { };
    if (!options.skipPackageJson) {
        if (tailwindInstalledVersion === undefined) {
            installTask = (0, add_tailwind_helpers_1.addTailwindRequiredPackages)(tree);
        }
    }
    (0, add_tailwind_helpers_1.addTailwindConfigFile)(tree, options, project);
    if (project.projectType === 'application') {
        (0, add_tailwind_helpers_1.updateApplicationStyles)(tree, options, project);
    }
    else if (project.projectType === 'library') {
        (0, add_tailwind_helpers_1.addTailwindConfigPathToProject)(tree, options, project);
    }
    if (!options.skipFormat) {
        await (0, devkit_1.formatFiles)(tree);
    }
    return installTask;
}
exports.setupTailwindGenerator = setupTailwindGenerator;
//# sourceMappingURL=add-tailwind-config.js.map